User guide
==========

.. toctree::
    :maxdepth: 2
    :hidden:

    channel_mapping
    background_subtraction
    molecule_localization
    trace_extraction
    trace_visualization
    trace_selection
    trace_classification
    hidden_markov_modelling
    dwell_time_analysis